@@ -285,6 +285,8 @@ CONF *conf_new(META *m, char *basepath, char *modbasepath)
 
 	/* Get the configuration file and compile it */
 
+	msg(F_MISC, L_NOTICE, "conf_new: Opening %s/" CONF_MAINFNAME "\n",
+	    basepath);
 	t = text_new(basepath, CONF_MAX_IDENTLEN + 1);
 	if (!t || text_include(t, CONF_MAINFNAME) == -1) {
 		if (basepath) msg(F_MISC, L_ERR, "conf_new: ERROR: Could not "
@@ -342,6 +344,8 @@ CONF *conf_new(META *m, char *basepath, char *modbasepath)
 
 	/* Use the same code buffer and text object to compile the behaviour */
 
+	msg(F_MISC, L_NOTICE, "conf_new: Opening %s/" EXPR_MAINFNAME "\n",
+	    basepath);
 	if (text_include(t, EXPR_MAINFNAME) == -1) {
 		if (basepath) msg(F_MISC, L_ERR, "conf_new: ERROR: Could not "
 						 "open file '" EXPR_MAINFNAME 
@@ -458,7 +462,7 @@ int conf_start(CONF *c, time_t t)
 		/* Create socket */
 		sock->fd = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
 		if (sock->fd == -1) {
-			msg(F_MISC, L_ERR, "conf_start: Could not create "
+			msg(F_RECV, L_ERR, "conf_start: Could not create "
 					   "socket: %s!\n", strerror(errno));
 			return -1;
 		}
@@ -471,6 +475,10 @@ int conf_start(CONF *c, time_t t)
 		   as it officially should. The first one to report that this
 		   is broken on his/her system gets a beer on the house. */
 		putord((char *)&(sin.sin_addr), sizeof(sin.sin_addr), sock->ip);
+
+		msg(F_RECV, L_NOTICE,"conf_start: Opening socket on %s, port "
+				   "%d\n", inet_ntoa(sin.sin_addr), sock->port);
+
 		if (bind(sock->fd, (struct sockaddr *)&sin, sizeof(sin)) == -1){
 
 			msg(F_MISC, L_ERR, "conf_start: Could not bind to %s, "
@@ -486,6 +494,10 @@ int conf_start(CONF *c, time_t t)
 
 	/* Start the subprograms */
 	for(proc = c->procs; proc; proc = proc->next) {
+
+		msg(F_PROC, L_NOTICE,"conf_start: Starting %s for %s\n",
+		    proc->argv[0], proc->chan->iface->name);
+
 		proc_start(proc, t);
 	}
 
